diff -aurw ./net-snmp/apps/snmpwalk.c ../src/snmpwalk.cpp > snmpwalk.patch
diff -aurw ./net-snmp/apps/snmpget.c ../src/snmpget.cpp > snmpget.patch
diff -aurw ./net-snmp/apps/snmpset.c ../src/snmpset.cpp > snmpset.patch
diff -aurw ./net-snmp/apps/snmptrap.c ../src/snmptrap.cpp > snmptrap.patch
diff -aurw ./net-snmp/apps/snmpbulkwalk.c ../src/snmpbulkwalk.cpp > snmpbulkwalk.patch
diff -aurw ./net-snmp/apps/snmpbulkget.c ../src/snmpbulkget.cpp > snmpbulkget.patch
diff -aurw ./net-snmp/apps/snmpgetnext.c ../src/snmpgetnext.cpp > snmpgetnext.patch